@@ -57,12 +57,16 @@ def keep_alive():
             sys.exit(16)
         sleep(15)
 
-while not mqttclient.is_connected():
+for i in range(5):
+    if mqttclient.is_connected():
+        break
     print("connecting to mqtt. . .")
     mqttclient.connect(MQTT_SERVER,1883, 60)
     mqttclient.loop()
     sleep(5)
-
+if not mqttclient.is_connected():
+    print("Could not connect tro MQTT server!, Exiting . . .")
+    sys.exit(23)
 print("mqtt connected!")
 
 print("subscribing to topics")
@@ -109,7 +113,7 @@ def handle_mqtt_messages(client, userdata, msg: mqtt.MQTTMessage):
                         r*brightness/255.0, g*brightness/255.0, b*brightness/255.0)
                 elif effect >= 2:
                     effector = led_effects.effects[effect]['class'](
-                        frame_time=0.1, led=led, brightness=brightness)
+                        frame_time=0.1, led=led, brightness=brightness, r=r, g=g, b=b)
         mqttclient.publish(MQTT_BASE_TOPIC+"/report/state",
                        "on" if state else "off")
     elif topic == MQTT_BASE_TOPIC+"/control/brightness":
@@ -157,7 +161,7 @@ def handle_mqtt_messages(client, userdata, msg: mqtt.MQTTMessage):
                     led.turn_off()
                 elif effect >= 2 and state:
                     effector = led_effects.effects[i]['class'](
-                        frame_time=0.1, led=led, brightness=brightness)
+                        frame_time=0.1, led=led, brightness=brightness, r=r, g=g, b=b)
         mqttclient.publish(MQTT_BASE_TOPIC+"/report/effect",
                        led_effects.effects[effect]['name'])
     elif topic == MQTT_BASE_TOPIC+"/control/exit":
