@@ -81,8 +81,8 @@ class random(effect):
   def draw_frame(self):
     self.array = numpy.random.randint(low=0,high=9,size=self.num_leds)
     for i in range(0,self.num_leds):
-        self.leds.set_led_at(i,r=int(self.brightness*self.color[self.array[i]][0]),g=int(self.brightness*self.color[self.array[i]][1]),b=int(self.brightness*self.color[self.array[i]][2]))
-    self.leds.show()
+        self.led.set_led_at(i,r=int(self.brightness*self.color[self.array[i]][0]),g=int(self.brightness*self.color[self.array[i]][1]),b=int(self.brightness*self.color[self.array[i]][2]))
+    self.led.show()
     
 
 class breathing_random(effect):
@@ -100,8 +100,8 @@ class breathing_random(effect):
     self.array = numpy.random.randint(low=0,high=9,size=self.num_leds)
     val = numpy.heaviside(time,1)*numpy.sin(time)
     for i in range(0,self.num_leds):
-      self.leds.set_led_at(i,r=int(self.brightness*self.color[self.array[i]][0]*val),g=int(self.brightness*self.color[self.array[i]][1]*val),b=int(self.brightness*self.color[self.array[i]][2]*val))
-    self.leds.show()
+      self.led.set_led_at(i,r=int(self.brightness*self.color[self.array[i]][0]*val),g=int(self.brightness*self.color[self.array[i]][1]*val),b=int(self.brightness*self.color[self.array[i]][2]*val))
+    self.led.show()
 
 class breathing(effect):
       # Slowly fade in and out with current colour
@@ -112,8 +112,8 @@ class breathing(effect):
     time *= 1000
     val = numpy.heaviside(time,1)*numpy.sin(time)
     for i in range(0,self.num_leds):
-      self.leds.set_led_at(i,r=int(self.brightness*self.r*val),g=int(self.brightness*self.g*val),b=int(self.brightness*self.b*val))
-    self.leds.show()
+      self.led.set_led_at(i,r=int(self.brightness*self.r*val),g=int(self.brightness*self.g*val),b=int(self.brightness*self.b*val))
+    self.led.show()
 
 class police(effect):
   # Strobe Red and Blue
@@ -125,11 +125,11 @@ class police(effect):
     time = time%1000
     if(time<500):
       for i in range(0,self.num_leds):
-        self.leds.set_led_at(i,r=int(self.brightness*1),g=0,b=0)
+        self.led.set_led_at(i,r=int(self.brightness*1),g=0,b=0)
     else:
       for i in range(0,self.num_leds):
-        self.leds.set_led_at(i,r=0,g=0,b=int(self.brightness*1))
-    self.leds.show()
+        self.led.set_led_at(i,r=0,g=0,b=int(self.brightness*1))
+    self.led.show()
 
 class starlight(effect):
   #Pop up a random color at random position then fade away
@@ -144,8 +144,8 @@ class starlight(effect):
     # TODO Implement This Function
     self.array = numpy.random.randint(low=0,high=9,size=self.num_leds)
     for i in range(0,self.num_leds):
-        self.leds.set_led_at(i,r=int(self.brightness*self.color[self.array[i]][0]),g=int(self.brightness*self.color[self.array[i]][1]),b=int(self.brightness*self.color[self.array[i]][2]))
-    self.leds.show()
+        self.led.set_led_at(i,r=int(self.brightness*self.color[self.array[i]][0]),g=int(self.brightness*self.color[self.array[i]][1]),b=int(self.brightness*self.color[self.array[i]][2]))
+    self.led.show()
 
 
 effects = [
